#!/bin/bash

LOGGING_OPTS="-Dorg.slf4j.simpleLogger.defaultLogLevel=warn"
JAVA_VERSION_MIN=8

which java > /dev/null
if [ $? -ne 0 ];then
  echo "Install Java version $JAVA_VERSION_MIN or higher"
  exit -1
fi

java_major=`java -version 2>&1 | grep ' version "[0-9_\.]*"' | cut -f2 -d'"' | cut -f1 -d'.'`
java_minor=`java -version 2>&1 | grep ' version "[0-9_\.]*"' | cut -f2 -d'"' | cut -f2 -d'.'`

if [ -z $java_major ] || [ -z $java_minor ];then
  echo "Unable to parse Java version: $(java -version). Format start with <major>.<minor>"
fi

if [ $java_major -eq 1 ] && [ $java_minor -lt $JAVA_VERSION_MIN  ];then
  echo "Java version is `java -version 2>&1 | grep ' version "[0-9_\.]*"' | cut -f2 -d'"'`"
  echo "Install Java version $JAVA_VERSION_MIN or higher"
  exit -1
fi

if [ ! -f $JAR_FILE ];then
  echo "$JAR_FILE is not a valid file"
  exit -1
fi

if [ ! -f $BC_CLASS_PATH ];then
  echo "$BC_CLASS_PATH is not a valid file"
  exit -1
fi

if [ ! -f $BCPKIX_CLASS_PATH ];then
  echo "$BCPKIX_CLASS_PATH is not a valid file"
  exit -1
fi

# pass all arguments from command line
java $LOGGING_OPTS -cp $BC_CLASS_PATH:$BCPKIX_CLASS_PATH:$JAR_FILE com.oracle.pic.rhino.cli.RhinoCli ${1+"$@"}
